@@ -19,7 +19,6 @@
 # SOFTWARE.
 
 import json
-import logging
 import time
 
 import numpy as np
@@ -99,8 +98,6 @@ class SimpleClassifierList:
         the ranked list of SimpleClassifiers
     metric : str {auto, jaccard, f1}
         the scoring metric for ranking models
-    logger : logging.Logger
-        logger for notifying user of warnings
 
     Methods
     -------
@@ -169,11 +166,7 @@ class SimpleClassifierList:
                     n_jobs=-1,
                 )
                 start = time.time()
-                try:
-                    grid_clf.fit(train_x, train_y)
-                except BaseException as error:
-                    self.logger.warning(f"{name} failed due to, Error : {error}.")
-                    continue
+                grid_clf.fit(train_x, train_y)
                 end = time.time()
                 clf = SimpleClassifier()
                 clf.metrics["Training Accuracy"] = grid_clf.best_score_
